The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {gaussfacts}


Type: Package
Title: The Greatest Mathematician Since Antiquity
Version: 0.0.4
Date: 2026-09-01
Description: Display a random fact about Carl Friedrich Gauss based on the collection curated by Mike Cavers via the https://web.archive.org/web/*/gaussfacts.com site.
URL: https://github.com/eddelbuettel/gaussfacts, https://dirk.eddelbuettel.com/code/gaussfacts.html
BugReports: https://github.com/eddelbuettel/gaussfacts/issues
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2026-09-01 13:15:02 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre], Mike Cavers [aut] (<https://web.archive.org/web/*/gaussfacts.com> site)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-09-01 14:00:10 UTC

Display a Random Fact about Carl Friedrich Gauss

Description

Function to display a randomly chosen fact about Carl Friedrich Gauss

Usage

gaussfact(ind)

## S3 method for class 'gaussfact'
print(x, width = NULL, ...)

Arguments

ind

Optional index of a quote, or character expression to be matched; if missing a random index value is sampled

x

Default object for print method

width

Optional column width parameter

...

Other optional arguments

Details

This function displays a randomly chosen line from the included data set of random ‘facts’ about Carl Friedrich Gauss. It is based on corpus curated by Mike Cavers via the https://web.archive.org/web/*/gaussfacts.com site, and kindly made available.

Value

A character vector containing one randomly selected line from the included file. It is of class gaussfact for which an S3 print method will be invoked.

Author(s)

Dirk Eddelbuettel

Examples

  set.seed(123)
  gaussfact()

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.