| Title: | The Greatest Mathematician Since Antiquity |
|---|---|
| Description: | Display a random fact about Carl Friedrich Gauss based the on collection curated by Mike Cavers via the <https://web.archive.org/web/*/gaussfacts.com> site. |
| Authors: | Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), Mike Cavers [aut] (<https://web.archive.org/web/*/gaussfacts.com> site) |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.2.1 |
| Built: | 2026-05-31 10:16:51 UTC |
| Source: | https://github.com/eddelbuettel/gaussfacts |
Function to display a randomly chosen fact about Carl Friedrich Gauss
gaussfact(ind) ## S3 method for class 'gaussfact' print(x, width = NULL, ...)gaussfact(ind) ## S3 method for class 'gaussfact' print(x, width = NULL, ...)
ind |
Optional index of a quote; if missing a random value is sampled |
x |
Default object for |
width |
Optional column width parameter |
... |
Other optional arguments |
This function displays a randomly chosen line from the included data set of of random ‘facts’ about Carl Friedrich Gauss. It is based on corpus curated by Mike Cavers via the https://web.archive.org/web/*/gaussfacts.com site, and kindly made available.
A character vector containing one randomly selected line
from the included file. It is of class gaussfact for
which an S3 print method will be invoked.
Dirk Eddelbuettel
set.seed(123) gaussfact()set.seed(123) gaussfact()