Package {gaussfacts}


Type: Package
Title: The Greatest Mathematician Since Antiquity
Version: 0.0.3
Date: 2026-08-23
Description: Display a random fact about Carl Friedrich Gauss based on the collection curated by Mike Cavers via the https://web.archive.org/web/*/gaussfacts.com site.
URL: https://github.com/eddelbuettel/gaussfacts, http://dirk.eddelbuettel.com/code/gaussfacts.html
BugReports: https://github.com/eddelbuettel/gaussfacts/issues
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2026-08-23 19:28:26 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre], Mike Cavers [aut] (<https://web.archive.org/web/*/gaussfacts.com> site)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-08-23 20:20:02 UTC

Display a Random Fact about Carl Friedrich Gauss

Description

Function to display a randomly chosen fact about Carl Friedrich Gauss

Usage

gaussfact(ind)

## S3 method for class 'gaussfact'
print(x, width = NULL, ...)

Arguments

ind

Optional index of a quote; if missing a random value is sampled

x

Default object for print method

width

Optional column width parameter

...

Other optional arguments

Details

This function displays a randomly chosen line from the included data set of random ‘facts’ about Carl Friedrich Gauss. It is based on corpus curated by Mike Cavers via the https://web.archive.org/web/*/gaussfacts.com site, and kindly made available.

Value

A character vector containing one randomly selected line from the included file. It is of class gaussfact for which an S3 print method will be invoked.

Author(s)

Dirk Eddelbuettel

Examples

  set.seed(123)
  gaussfact()